@@ -3,7 +3,10 @@ import json
 import os
 import logging
 import logging.handlers
-import pandas as pd
+try:
+    import pandas as pd
+except:
+    pass
 from datetime import datetime, timedelta
 import pytz
 import grpc
